# create rsyslog.conf

define base::syslog::config::rsyslog(
    $ensure          = 'present',
    $source          = undef,
    $owner           = 'root',
    $group           = 'root',
    $mode            = '0644',
    $replace         = true,
    $use_syslog_conf = true,
) {

  if !$use_syslog_conf {
    file {
      '/etc/syslog.conf':
        ensure => absent;
      '/etc/rsyslog.d/90-local.conf':
        ensure  => present,
        source  => 'puppet:///modules/base/syslog/etc/rsyslog.d/90-local.conf',
        owner   => $owner,
        group   => $group,
        mode    => $mode;
    }
  }

  # Template for the base rsyslog configuration.
  if $source {
    $template = undef
  } else {
    $template = template('base/syslog/rsyslog.conf.erb')
  }
  file { $name:
    ensure  => $ensure,
    source  => $source,
    content => $template,
    owner   => $owner,
    group   => $group,
    mode    => $mode,
    replace => $replace,
    notify  => Service['syslog'],
  }
}
